summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-19 18:44:25 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-19 18:44:25 +0000
commitf3d91332267efafe2f6ffde1eb5b7f3ca48fcbfc (patch)
treedc3f25285e39cdcaf58489cc3a499a7bd8816c09
parentabbfa2ecec4464862ce2707972aa43bb5b2fb475 (diff)
downloadkoffice-f3d91332.tar.gz
koffice-f3d91332.zip
Rename tqgeometry* to geometry*
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1242307 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
-rw-r--r--filters/kword/pdf/xpdf/xpdf/XPDFTree.cc6
-rw-r--r--karbon/core/vpath.cc2
-rw-r--r--kivio/kiviopart/kivio_view.cpp6
-rw-r--r--kspread/kspread_handler.cc58
-rw-r--r--kspread/kspread_handler.h4
-rw-r--r--lib/kofficecore/KoContainerHandler.cpp70
-rw-r--r--lib/kofficecore/KoFrame.cpp6
-rw-r--r--lib/kofficecore/KoFrame.h2
-rw-r--r--lib/kofficecore/KoView.cpp2
9 files changed, 78 insertions, 78 deletions
diff --git a/filters/kword/pdf/xpdf/xpdf/XPDFTree.cc b/filters/kword/pdf/xpdf/xpdf/XPDFTree.cc
index 3440bf1c7..28e01de6c 100644
--- a/filters/kword/pdf/xpdf/xpdf/XPDFTree.cc
+++ b/filters/kword/pdf/xpdf/xpdf/XPDFTree.cc
@@ -41,7 +41,7 @@ static void setValuesAlmost(Widget oldWidget, Widget newWidget,
static XtGeometryResult queryGeometry(Widget widget,
XtWidgetGeometry *request,
XtWidgetGeometry *reply);
-static XtGeometryResult tqgeometryManager(Widget widget,
+static XtGeometryResult geometryManager(Widget widget,
XtWidgetGeometry *request,
XtWidgetGeometry *reply);
static void changeManaged(Widget widget);
@@ -163,7 +163,7 @@ externaldef(xpdftreeclassrec) XPDFTreeClassRec xpdfTreeClassRec = {
NULL // extension
},
{ // Composite
- &tqgeometryManager, // tqgeometry_manager
+ &geometryManager, // geometry_manager
&changeManaged, // change_managed
XtInheritInsertChild, // insert_child
XtInheritDeleteChild, // delete_child
@@ -440,7 +440,7 @@ static XtGeometryResult queryGeometry(Widget widget,
#endif
}
-static XtGeometryResult tqgeometryManager(Widget widget,
+static XtGeometryResult geometryManager(Widget widget,
XtWidgetGeometry *request,
XtWidgetGeometry *reply) {
XPDFTreeWidget w = (XPDFTreeWidget)XtParent(widget);
diff --git a/karbon/core/vpath.cc b/karbon/core/vpath.cc
index a198eb525..4f279cd7f 100644
--- a/karbon/core/vpath.cc
+++ b/karbon/core/vpath.cc
@@ -423,7 +423,7 @@ VSubpath::pointIsInside( const KoPoint& p ) const
// as lines).
/* This algorithm is taken from "Fast Winding Number Inclusion of a Point
- * in a Polygon" by Dan Sunday, tqgeometryalgorithms.com.
+ * in a Polygon" by Dan Sunday, geometryalgorithms.com.
*/
/*
diff --git a/kivio/kiviopart/kivio_view.cpp b/kivio/kiviopart/kivio_view.cpp
index d38690d92..664d8af47 100644
--- a/kivio/kiviopart/kivio_view.cpp
+++ b/kivio/kiviopart/kivio_view.cpp
@@ -274,7 +274,7 @@ KivioView::KivioView( TQWidget *_parent, const char *_name, KivioDoc* doc )
createGeometryDock();
createProtectionDock();
paletteManager()->showWidget("birdseyepanel");
- paletteManager()->showWidget("stenciltqgeometrypanel");
+ paletteManager()->showWidget("stencilgeometrypanel");
setupActions();
@@ -339,7 +339,7 @@ void KivioView::createGeometryDock()
m_pStencilGeometryPanel = new KivioStencilGeometryPanel(this);
m_pStencilGeometryPanel->setCaption(i18n("Geometry"));
m_pStencilGeometryPanel->setUnit(m_pDoc->unit());
- paletteManager()->addWidget(m_pStencilGeometryPanel, "stenciltqgeometrypanel", "tqgeometrydocker");
+ paletteManager()->addWidget(m_pStencilGeometryPanel, "stencilgeometrypanel", "geometrydocker");
connect( m_pStencilGeometryPanel, TQT_SIGNAL(positionChanged(double, double)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeStencilPosition(double, double)) );
connect( m_pStencilGeometryPanel, TQT_SIGNAL(sizeChanged(double, double)), TQT_TQOBJECT(this), TQT_SLOT(slotChangeStencilSize(double, double)) );
@@ -366,7 +366,7 @@ void KivioView::createProtectionDock()
{
m_pProtectionPanel = new KivioProtectionPanel(this,this);
m_pProtectionPanel->setCaption(i18n("Protection"));
- paletteManager()->addWidget(m_pProtectionPanel, "protectionpanel", "tqgeometrydocker");
+ paletteManager()->addWidget(m_pProtectionPanel, "protectionpanel", "geometrydocker");
}
void KivioView::createObjectListPalette()
diff --git a/kspread/kspread_handler.cc b/kspread/kspread_handler.cc
index 5adedbfdd..262774ffe 100644
--- a/kspread/kspread_handler.cc
+++ b/kspread/kspread_handler.cc
@@ -34,8 +34,8 @@ bool InsertHandler::eventFilter( TQObject*, TQEvent* ev )
{
TQMouseEvent* e = (TQMouseEvent*)ev;
- m_tqgeometryStart = e->pos();
- m_tqgeometryEnd = e->pos();
+ m_geometryStart = e->pos();
+ m_geometryEnd = e->pos();
m_started = false;
m_clicked = true;
@@ -58,15 +58,15 @@ bool InsertHandler::eventFilter( TQObject*, TQEvent* ev )
if ( m_started )
{
- int x = m_tqgeometryStart.x();
- int y = m_tqgeometryStart.y();
- if ( x > m_tqgeometryEnd.x() )
- x = m_tqgeometryEnd.x();
- if ( y > m_tqgeometryEnd.y() )
- y = m_tqgeometryEnd.y();
- int w = m_tqgeometryEnd.x() - m_tqgeometryStart.x();
+ int x = m_geometryStart.x();
+ int y = m_geometryStart.y();
+ if ( x > m_geometryEnd.x() )
+ x = m_geometryEnd.x();
+ if ( y > m_geometryEnd.y() )
+ y = m_geometryEnd.y();
+ int w = m_geometryEnd.x() - m_geometryStart.x();
if ( w < 0 ) w *= -1;
- int h = m_tqgeometryEnd.y() - m_tqgeometryStart.y();
+ int h = m_geometryEnd.y() - m_geometryStart.y();
if ( h < 0 ) h *= -1;
if ( w < KS_MIN_RECTSIZE ) w = KS_MIN_RECTSIZE;
@@ -77,17 +77,17 @@ bool InsertHandler::eventFilter( TQObject*, TQEvent* ev )
else
m_started = true;
- m_tqgeometryEnd = e->pos();
+ m_geometryEnd = e->pos();
- int x = m_tqgeometryStart.x();
- int y = m_tqgeometryStart.y();
- if ( x > m_tqgeometryEnd.x() )
- x = m_tqgeometryEnd.x();
- if ( y > m_tqgeometryEnd.y() )
- y = m_tqgeometryEnd.y();
- int w = m_tqgeometryEnd.x() - m_tqgeometryStart.x();
+ int x = m_geometryStart.x();
+ int y = m_geometryStart.y();
+ if ( x > m_geometryEnd.x() )
+ x = m_geometryEnd.x();
+ if ( y > m_geometryEnd.y() )
+ y = m_geometryEnd.y();
+ int w = m_geometryEnd.x() - m_geometryStart.x();
if ( w < 0 ) w *= -1;
- int h = m_tqgeometryEnd.y() - m_tqgeometryStart.y();
+ int h = m_geometryEnd.y() - m_geometryStart.y();
if ( h < 0 ) h *= -1;
if ( w < KS_MIN_RECTSIZE ) w = KS_MIN_RECTSIZE;
@@ -108,17 +108,17 @@ bool InsertHandler::eventFilter( TQObject*, TQEvent* ev )
return true;
}
- m_tqgeometryEnd = e->pos();
-
- int x = m_tqgeometryStart.x();
- int y = m_tqgeometryStart.y();
- if ( x > m_tqgeometryEnd.x() )
- x = m_tqgeometryEnd.x();
- if ( y > m_tqgeometryEnd.y() )
- y = m_tqgeometryEnd.y();
- int w = m_tqgeometryEnd.x() - m_tqgeometryStart.x();
+ m_geometryEnd = e->pos();
+
+ int x = m_geometryStart.x();
+ int y = m_geometryStart.y();
+ if ( x > m_geometryEnd.x() )
+ x = m_geometryEnd.x();
+ if ( y > m_geometryEnd.y() )
+ y = m_geometryEnd.y();
+ int w = m_geometryEnd.x() - m_geometryStart.x();
if ( w < 0 ) w *= -1;
- int h = m_tqgeometryEnd.y() - m_tqgeometryStart.y();
+ int h = m_geometryEnd.y() - m_geometryStart.y();
if ( h < 0 ) h *= -1;
if ( w < KS_MIN_RECTSIZE ) w = KS_MIN_RECTSIZE;
diff --git a/kspread/kspread_handler.h b/kspread/kspread_handler.h
index 5a54736b5..0c4d911ff 100644
--- a/kspread/kspread_handler.h
+++ b/kspread/kspread_handler.h
@@ -40,8 +40,8 @@ protected:
virtual void insertObject( TQRect ) = 0;
View* m_view;
- TQPoint m_tqgeometryStart;
- TQPoint m_tqgeometryEnd;
+ TQPoint m_geometryStart;
+ TQPoint m_geometryEnd;
bool m_started;
bool m_clicked;
};
diff --git a/lib/kofficecore/KoContainerHandler.cpp b/lib/kofficecore/KoContainerHandler.cpp
index 1f21df24b..bd4bb4894 100644
--- a/lib/kofficecore/KoContainerHandler.cpp
+++ b/lib/kofficecore/KoContainerHandler.cpp
@@ -47,7 +47,7 @@ public:
KoChild::Gadget gadget, const TQPoint& point ) :
m_gadget(gadget), m_view(view), m_child(child), m_parentMatrix(matrix) {
- m_tqgeometryStart = child->tqgeometry();
+ m_geometryStart = child->tqgeometry();
m_matrix = child->matrix() * matrix;
m_invertParentMatrix = matrix.invert();
@@ -60,7 +60,7 @@ public:
KoChild::Gadget m_gadget;
TQPoint m_mouseStart;
- TQRect m_tqgeometryStart;
+ TQRect m_geometryStart;
KoView* m_view;
KoChild* m_child;
TQWMatrix m_invert;
@@ -123,77 +123,77 @@ bool KoPartResizeHandler::eventFilter( TQObject*, TQEvent* ev )
{
case KoChild::TopLeft:
{
- x = TQMIN( d->m_tqgeometryStart.width() - 1, x );
- y = TQMIN( d->m_tqgeometryStart.height() - 1, y );
+ x = TQMIN( d->m_geometryStart.width() - 1, x );
+ y = TQMIN( d->m_geometryStart.height() - 1, y );
- d->m_child->setGeometry( TQRect( d->m_tqgeometryStart.x() + x, d->m_tqgeometryStart.y() + y,
- d->m_tqgeometryStart.width() - x, d->m_tqgeometryStart.height() - y ) );
+ d->m_child->setGeometry( TQRect( d->m_geometryStart.x() + x, d->m_geometryStart.y() + y,
+ d->m_geometryStart.width() - x, d->m_geometryStart.height() - y ) );
tqrepaint(rgn);
}
break;
case KoChild::TopMid:
{
- y = TQMIN( d->m_tqgeometryStart.height() - 1, y );
+ y = TQMIN( d->m_geometryStart.height() - 1, y );
- d->m_child->setGeometry( TQRect( d->m_tqgeometryStart.x(), d->m_tqgeometryStart.y() + y,
- d->m_tqgeometryStart.width(), d->m_tqgeometryStart.height() - y ) );
+ d->m_child->setGeometry( TQRect( d->m_geometryStart.x(), d->m_geometryStart.y() + y,
+ d->m_geometryStart.width(), d->m_geometryStart.height() - y ) );
tqrepaint(rgn);
}
break;
case KoChild::TopRight:
{
- x = TQMAX( -d->m_tqgeometryStart.width() + 1, x );
- y = TQMIN( d->m_tqgeometryStart.height() - 1, y );
+ x = TQMAX( -d->m_geometryStart.width() + 1, x );
+ y = TQMIN( d->m_geometryStart.height() - 1, y );
- d->m_child->setGeometry( TQRect( d->m_tqgeometryStart.x(), d->m_tqgeometryStart.y() + y,
- d->m_tqgeometryStart.width() + x, d->m_tqgeometryStart.height() - y ) );
+ d->m_child->setGeometry( TQRect( d->m_geometryStart.x(), d->m_geometryStart.y() + y,
+ d->m_geometryStart.width() + x, d->m_geometryStart.height() - y ) );
tqrepaint(rgn);
}
break;
case KoChild::MidLeft:
{
- x = TQMIN( d->m_tqgeometryStart.width() - 1, x );
+ x = TQMIN( d->m_geometryStart.width() - 1, x );
- d->m_child->setGeometry( TQRect( d->m_tqgeometryStart.x() + x, d->m_tqgeometryStart.y(),
- d->m_tqgeometryStart.width() - x, d->m_tqgeometryStart.height() ) );
+ d->m_child->setGeometry( TQRect( d->m_geometryStart.x() + x, d->m_geometryStart.y(),
+ d->m_geometryStart.width() - x, d->m_geometryStart.height() ) );
tqrepaint(rgn);
}
break;
case KoChild::MidRight:
{
- x = TQMAX( -d->m_tqgeometryStart.width() + 1, x );
+ x = TQMAX( -d->m_geometryStart.width() + 1, x );
- d->m_child->setGeometry( TQRect( d->m_tqgeometryStart.x(), d->m_tqgeometryStart.y(),
- d->m_tqgeometryStart.width() + x, d->m_tqgeometryStart.height() ) );
+ d->m_child->setGeometry( TQRect( d->m_geometryStart.x(), d->m_geometryStart.y(),
+ d->m_geometryStart.width() + x, d->m_geometryStart.height() ) );
tqrepaint(rgn);
}
break;
case KoChild::BottomLeft:
{
- x = TQMIN( d->m_tqgeometryStart.width() - 1, x );
- y = TQMAX( -d->m_tqgeometryStart.height() + 1, y );
+ x = TQMIN( d->m_geometryStart.width() - 1, x );
+ y = TQMAX( -d->m_geometryStart.height() + 1, y );
- d->m_child->setGeometry( TQRect( d->m_tqgeometryStart.x() + x, d->m_tqgeometryStart.y(),
- d->m_tqgeometryStart.width() - x, d->m_tqgeometryStart.height() + y ) );
+ d->m_child->setGeometry( TQRect( d->m_geometryStart.x() + x, d->m_geometryStart.y(),
+ d->m_geometryStart.width() - x, d->m_geometryStart.height() + y ) );
tqrepaint(rgn);
}
break;
case KoChild::BottomMid:
{
- y = TQMAX( -d->m_tqgeometryStart.height() + 1, y );
+ y = TQMAX( -d->m_geometryStart.height() + 1, y );
- d->m_child->setGeometry( TQRect( d->m_tqgeometryStart.x(), d->m_tqgeometryStart.y(),
- d->m_tqgeometryStart.width(), d->m_tqgeometryStart.height() + y ) );
+ d->m_child->setGeometry( TQRect( d->m_geometryStart.x(), d->m_geometryStart.y(),
+ d->m_geometryStart.width(), d->m_geometryStart.height() + y ) );
tqrepaint(rgn);
}
break;
case KoChild::BottomRight:
{
- x = TQMAX( -d->m_tqgeometryStart.width() + 1, x );
- y = TQMAX( -d->m_tqgeometryStart.height() + 1, y );
+ x = TQMAX( -d->m_geometryStart.width() + 1, x );
+ y = TQMAX( -d->m_geometryStart.height() + 1, y );
- d->m_child->setGeometry( TQRect( d->m_tqgeometryStart.x(), d->m_tqgeometryStart.y(),
- d->m_tqgeometryStart.width() + x, d->m_tqgeometryStart.height() + y ) );
+ d->m_child->setGeometry( TQRect( d->m_geometryStart.x(), d->m_geometryStart.y(),
+ d->m_geometryStart.width() + x, d->m_geometryStart.height() + y ) );
tqrepaint(rgn);
}
break;
@@ -214,7 +214,7 @@ public:
m_parentMatrix(matrix) {
m_invertParentMatrix = matrix.invert();
m_mouseDragStart = m_invertParentMatrix.map( point );
- m_tqgeometryDragStart = m_dragChild->tqgeometry();
+ m_geometryDragStart = m_dragChild->tqgeometry();
m_rotationDragStart = m_dragChild->rotationPoint();
}
~KoPartMoveHandlerPrivate() {}
@@ -222,7 +222,7 @@ public:
KoView* m_view;
KoChild* m_dragChild;
TQPoint m_mouseDragStart;
- TQRect m_tqgeometryDragStart;
+ TQRect m_geometryDragStart;
TQPoint m_rotationDragStart;
TQWMatrix m_invertParentMatrix;
TQWMatrix m_parentMatrix;
@@ -256,9 +256,9 @@ bool KoPartMoveHandler::eventFilter( TQObject*, TQEvent* ev )
TQRegion bound = d->m_dragChild->frameRegion( d->m_parentMatrix, true );
TQPoint pos = d->m_invertParentMatrix.map( e->pos() /* + TQPoint(d->m_view->canvasXOffset(), d->m_view->canvasYOffset()) */ );
- d->m_dragChild->setGeometry( TQRect( d->m_tqgeometryDragStart.x() + pos.x() - d->m_mouseDragStart.x(),
- d->m_tqgeometryDragStart.y() + pos.y() - d->m_mouseDragStart.y(),
- d->m_tqgeometryDragStart.width(), d->m_tqgeometryDragStart.height() ) );
+ d->m_dragChild->setGeometry( TQRect( d->m_geometryDragStart.x() + pos.x() - d->m_mouseDragStart.x(),
+ d->m_geometryDragStart.y() + pos.y() - d->m_mouseDragStart.y(),
+ d->m_geometryDragStart.width(), d->m_geometryDragStart.height() ) );
d->m_dragChild->setRotationPoint( TQPoint( d->m_rotationDragStart.x() + pos.x() - d->m_mouseDragStart.x(),
d->m_rotationDragStart.y() + pos.y() - d->m_mouseDragStart.y() ) );
bound = bound.unite( d->m_dragChild->frameRegion( d->m_parentMatrix, false ) );
diff --git a/lib/kofficecore/KoFrame.h b/lib/kofficecore/KoFrame.h
index 7b372b987..fbb40bbbd 100644
--- a/lib/kofficecore/KoFrame.h
+++ b/lib/kofficecore/KoFrame.h
@@ -49,7 +49,7 @@ public:
virtual int border() const;
signals:
- void tqgeometryChanged();
+ void geometryChanged();
protected:
virtual void paintEvent( TQPaintEvent* );
diff --git a/lib/kofficecore/KoView.cpp b/lib/kofficecore/KoView.cpp
index cebd61be4..87751a341 100644
--- a/lib/kofficecore/KoView.cpp
+++ b/lib/kofficecore/KoView.cpp
@@ -852,7 +852,7 @@ void KoViewChild::setInitialFrameGeometry()
kdDebug() << k_funcinfo << endl;
// Connect only now, so that the GUI building doesn't move us around.
- connect( m_frame, TQT_SIGNAL( tqgeometryChanged() ),
+ connect( m_frame, TQT_SIGNAL( geometryChanged() ),
this, TQT_SLOT( slotFrameGeometryChanged() ) );
connect( m_child, TQT_SIGNAL( changed( KoChild * ) ),
this, TQT_SLOT( slotDocGeometryChanged() ) );
diff --git a/lib/kofficecore/KoFrame.cpp b/lib/kofficecore/KoFrame.cpp
index e8722eaa4..2662169e1 100644
--- a/lib/kofficecore/KoFrame.cpp
+++ b/lib/kofficecore/KoFrame.cpp
@@ -255,8 +255,8 @@ void KoFrame::mouseMoveEvent( TQMouseEvent* ev )
move( TQPoint( p.x() + d->m_framePos.x() - d->m_mousePressPos.x(),
p.y() + d->m_framePos.y() - d->m_mousePressPos.y() ) );
// The other modes change the tqgeometry so they call resizeEvent.
- // This one doesn't, so it has to emit tqgeometryChangedby itself.
- emit tqgeometryChanged();
+ // This one doesn't, so it has to emit geometryChangedby itself.
+ emit geometryChanged();
//kdDebug() << "KoFrame::mouseMoveEvent koFrame position is " << x() << "," << y() << endl;
}
else if ( d->m_mode == 1 )
@@ -357,7 +357,7 @@ void KoFrame::resizeEvent( TQResizeEvent* )
else
d->m_view->setGeometry( 0, 0, width(), height() );
- emit tqgeometryChanged();
+ emit geometryChanged();
}
bool KoFrame::eventFilter( TQObject* obj, TQEvent* ev )